% Auto-generated chapter 15 for bukhari
% Hadiths in this chapter: 34

\hadithdefcmd{bukhari}{1005}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم يَسْتَسْقِي وَحَوَّلَ رِدَاءَهُ‏.‏\hadithno{1005}\hadithtrans{Narrated `Abbad bin Tamim's uncle:The Prophet (ﷺ) went out to offer the Istisqa' prayer and turned (and put on) his cloak inside out}}
\hadithdefcmd{bukhari}{1006}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَفَعَ رَأْسَهُ مِنَ الرَّكْعَةِ الآخِرَةِ يَقُولُ ‏"‏ اللَّهُمَّ أَنْجِ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ، اللَّهُمَّ أَنْجِ سَلَمَةَ بْنَ هِشَامٍ، اللَّهُمَّ أَنْجِ الْوَلِيدَ بْنَ الْوَلِيدِ، اللَّهُمَّ أَنْجِ الْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ، اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ، اللَّهُمَّ اجْعَلْهَا سِنِينَ كَسِنِي يُوسُفَ ‏"‏‏.‏ وَأَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ غِفَارُ غَفَرَ اللَّهُ لَهَا، وَأَسْلَمُ سَالَمَهَا اللَّهُ ‏"‏‏.‏ قَالَ ابْنُ أَبِي الزِّنَادِ عَنْ أَبِيهِ هَذَا كُلُّهُ فِي الصُّبْحِ‏.‏\hadithno{1006}\hadithtrans{Narrated Abu Huraira;:Whenever the Prophet (ﷺ) lifted his head from the bowing in the last rak`a he used to say: "O Allah! Save `Aiyash bin Abi Rabi`a. O Allah! Save Salama bin Hisham. O Allah! Save Walid bin Walid. O Allah! Save the weak faithful believers. O Allah! Be hard on the tribes of Mudar and send (famine) years on them like the famine years of (Prophet) Joseph ." The Prophet (ﷺ) further said, "Allah forgive the tribes of Ghifar and save the tribes of Aslam." Abu Az-Zinad (a sub-narrator) said, "The Qunut used to be recited by the Prophet (ﷺ) in the Fajr prayer}}
\hadithdefcmd{bukhari}{1007}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ كُنَّا عِنْدَ عَبْدِ اللَّهِ فَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا رَأَى مِنَ النَّاسِ إِدْبَارًا قَالَ ‏"‏ اللَّهُمَّ سَبْعٌ كَسَبْعِ يُوسُفَ ‏"‏‏.‏ فَأَخَذَتْهُمْ سَنَةٌ حَصَّتْ كُلَّ شَىْءٍ حَتَّى أَكَلُوا الْجُلُودَ وَالْمَيْتَةَ وَالْجِيَفَ، وَيَنْظُرَ أَحَدُهُمْ إِلَى السَّمَاءِ فَيَرَى الدُّخَانَ مِنَ الْجُوعِ، فَأَتَاهُ أَبُو سُفْيَانَ فَقَالَ يَا مُحَمَّدُ إِنَّكَ تَأْمُرُ بِطَاعَةِ اللَّهِ وَبِصِلَةِ الرَّحِمِ وَإِنَّ قَوْمَكَ قَدْ هَلَكُوا، فَادْعُ اللَّهَ لَهُمْ قَالَ اللَّهُ تَعَالَى ‏\{‏فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ‏\}‏ إِلَى قَوْلِهِ ‏\{‏عَائِدُونَ * يَوْمَ نَبْطِشُ الْبَطْشَةَ الْكُبْرَى‏\}‏ فَالْبَطْشَةُ يَوْمَ بَدْرٍ، وَقَدْ مَضَتِ الدُّخَانُ وَالْبَطْشَةُ وَاللِّزَامُ وَآيَةُ الرُّومِ‏.‏\hadithno{1007}\hadithtrans{Narrated Masruq:We were with `Abdullah and he said, "When the Prophet (ﷺ) saw the refusal of the people to accept Islam he said, "O Allah! Send (famine) years on them for (seven years) like the seven years (of famine during the time) of (Prophet) Joseph." So famine overtook them for one year and destroyed every kind of life to such an extent that the people started eating hides, carcasses and rotten dead animals. Whenever one of them looked towards the sky, he would (imagine himself to) see smoke because of hunger. So Abu Sufyan went to the Prophet (ﷺ) and said, "O Muhammad! You order people to obey Allah and to keep good relations with kith and kin. No doubt the people of your tribe are dying, so please pray to Allah for them." So Allah revealed: "Then watch you For the day that The sky will bring forth a kind Of smoke Plainly visible ... Verily! You will return (to disbelief) On the day when We shall seize You with a mighty grasp. (44.10-16) Ibn Mas`ud added, "Al-Batsha (i.e. grasp) happened in the battle of Badr and no doubt smoke, Al-Batsha, Al-Lizam, and the verse of Surat Ar-Rum have all passed}}
\hadithdefcmd{bukhari}{1009}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو قُتَيْبَةَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَتَمَثَّلُ بِشِعْرِ أَبِي طَالِبٍ وَأَبْيَضَ يُسْتَسْقَى الْغَمَامُ بِوَجْهِهِ ثِمَالُ الْيَتَامَى عِصْمَةٌ لِلأَرَامِلِ وَقَالَ عُمَرُ بْنُ حَمْزَةَ حَدَّثَنَا سَالِمٌ، عَنْ أَبِيهِ، رُبَّمَا ذَكَرْتُ قَوْلَ الشَّاعِرِ وَأَنَا أَنْظُرُ، إِلَى وَجْهِ النَّبِيِّ صلى الله عليه وسلم يَسْتَسْقِي، فَمَا يَنْزِلُ حَتَّى يَجِيشَ كُلُّ مِيزَابٍ‏.‏ وَأَبْيَضَ يُسْتَسْقَى الْغَمَامُ بِوَجْهِهِ ثِمَالَ الْيَتَامَى عِصْمَةً لِلأَرَامِلِ وَهْوَ قَوْلُ أَبِي طَالِبٍ‏.‏\hadithno{1009}\hadithtrans{Narrated `Abdullah bin Dinar:My father said, "I heard Ibn `Umar reciting the poetic verses of Abu Talib: And a white (person) (i.e. the Prophet) who is requested to pray for rain and who takes care of the orphans and is the guardian of widows." Salim's father (Ibn `Umar) said, "The following poetic verse occurred to my mind while I was looking at the face of the Prophet (ﷺ) while he was praying for rain. He did not get down till the rain water flowed profusely from every roof-gutter: And a white (person) who is requested to pray for rain and who takes care of the orphans and is the guardian of widows . . . And these were the words of Abu Talib}}
\hadithdefcmd{bukhari}{1010}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَبِي عَبْدُ اللَّهِ بْنُ الْمُثَنَّى، عَنْ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَنَسٍ، عَنْ أَنَسٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ كَانَ إِذَا قَحَطُوا اسْتَسْقَى بِالْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ فَقَالَ اللَّهُمَّ إِنَّا كُنَّا نَتَوَسَّلُ إِلَيْكَ بِنَبِيِّنَا فَتَسْقِينَا وَإِنَّا نَتَوَسَّلُ إِلَيْكَ بِعَمِّ نَبِيِّنَا فَاسْقِنَا‏.‏ قَالَ فَيُسْقَوْنَ‏.‏\hadithno{1010}\hadithtrans{Narrated Anas:Whenever drought threatened them, `Umar bin Al-Khattab, used to ask Al-Abbas bin `Abdul Muttalib to invoke Allah for rain. He used to say, "O Allah! We used to ask our Prophet to invoke You for rain, and You would bless us with rain, and now we ask his uncle to invoke You for rain. O Allah ! Bless us with rain."(1) And so it would rain}}
\hadithdefcmd{bukhari}{1011}{حَدَّثَنَا إِسْحَاقُ، قَالَ حَدَّثَنَا وَهْبٌ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَسْقَى فَقَلَبَ رِدَاءَهُ‏.‏\hadithno{1011}\hadithtrans{Narrated `Abdullah bin Zaid:The Prophet (ﷺ) turned his cloak inside out on Istisqa}}
\hadithdefcmd{bukhari}{1012}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ أَنَّهُ سَمِعَ عَبَّادَ بْنَ تَمِيمٍ، يُحَدِّثُ أَبَاهُ عَنْ عَمِّهِ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ إِلَى الْمُصَلَّى فَاسْتَسْقَى، فَاسْتَقْبَلَ الْقِبْلَةَ، وَقَلَبَ رِدَاءَهُ، وَصَلَّى رَكْعَتَيْنِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ كَانَ ابْنُ عُيَيْنَةَ يَقُولُ هُوَ صَاحِبُ الأَذَانِ، وَلَكِنَّهُ وَهْمٌ، لأَنَّ هَذَا عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ عَاصِمٍ الْمَازِنِيُّ، مَازِنُ الأَنْصَارِ‏.‏\hadithno{1012}\hadithtrans{Narrated `Abdullah bin Zaid:The Prophet (ﷺ) went towards the Musalla and invoked Allah for rain. He faced the Qibla and wore his cloak inside out, and offered two rak`at}}
\hadithdefcmd{bukhari}{1013}{حَدَّثَنَا مُحَمَّدٌ، قَالَ أَخْبَرَنَا أَبُو ضَمْرَةَ، أَنَسُ بْنُ عِيَاضٍ قَالَ حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَذْكُرُ أَنَّ رَجُلاً، دَخَلَ يَوْمَ الْجُمُعَةِ مِنْ باب كَانَ وُجَاهَ الْمِنْبَرِ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يَخْطُبُ فَاسْتَقْبَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَائِمًا فَقَالَ يَا رَسُولَ اللَّهِ، هَلَكَتِ الْمَوَاشِي وَانْقَطَعَتِ السُّبُلُ، فَادْعُ اللَّهَ يُغِيثُنَا‏.‏ قَالَ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ اسْقِنَا، اللَّهُمَّ اسْقِنَا، اللَّهُمَّ اسْقِنَا ‏"‏‏.‏ قَالَ أَنَسٌ وَلاَ وَاللَّهِ مَا نَرَى فِي السَّمَاءِ مِنْ سَحَابٍ وَلاَ قَزَعَةً وَلاَ شَيْئًا، وَمَا بَيْنَنَا وَبَيْنَ سَلْعٍ مِنْ بَيْتٍ وَلاَ دَارٍ، قَالَ فَطَلَعَتْ مِنْ وَرَائِهِ سَحَابَةٌ مِثْلُ التُّرْسِ، فَلَمَّا تَوَسَّطَتِ السَّمَاءَ انْتَشَرَتْ ثُمَّ أَمْطَرَتْ‏.‏ قَالَ وَاللَّهِ مَا رَأَيْنَا الشَّمْسَ سِتًّا، ثُمَّ دَخَلَ رَجُلٌ مِنْ ذَلِكَ الْبَابِ فِي الْجُمُعَةِ الْمُقْبِلَةِ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يَخْطُبُ، فَاسْتَقْبَلَهُ قَائِمًا فَقَالَ يَا رَسُولَ اللَّهِ، هَلَكَتِ الأَمْوَالُ وَانْقَطَعَتِ السُّبُلُ، فَادْعُ اللَّهَ يُمْسِكْهَا، قَالَ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا، اللَّهُمَّ عَلَى الآكَامِ وَالْجِبَالِ وَالآجَامِ وَالظِّرَابِ وَالأَوْدِيَةِ وَمَنَابِتِ الشَّجَرِ ‏"‏‏.‏ قَالَ فَانْقَطَعَتْ وَخَرَجْنَا نَمْشِي فِي الشَّمْسِ‏.‏ قَالَ شَرِيكٌ فَسَأَلْتُ أَنَسًا أَهُوَ الرَّجُلُ الأَوَّلُ قَالَ لاَ أَدْرِي‏.‏\hadithno{1013}\hadithtrans{Narrated Sharik bin `Abdullah bin Abi Namir:I heard Anas bin Malik saying, "On a Friday a person entered the main Mosque through the gate facing the pulpit while Allah's Messenger (ﷺ) was delivering the Khutba. The man stood in front of Allah's Apostle and said, 'O Allah's Messenger (ﷺ)! The livestock are dying and the roads are cut off; so please pray to Allah for rain.' " Anas added, "Allah's Messenger (ﷺ) raised both his hands and said, 'O Allah! Bless us with rain! O Allah! Bless us with rain! O Allah! Bless us with rain!' " Anas added, "By Allah, we could not see any trace of cloud in the sky and there was no building or a house between us and (the mountains of) Sila." Anas added, "A heavy cloud like a shield appeared from behind it (i.e. Sila' Mountain). When it came in the middle of the sky, it spread and then rained." Anas further said, "By Allah! We could not see the sun for a week. Next Friday a person entered through the same gate and at that time Allah's Messenger (ﷺ) was delivering the Friday's Khutba. The man stood in front of him and said, 'O Allah's Messenger (ﷺ)! The livestock are dying and the roads are cut off, please pray to Allah to withhold rain.'" Anas added, "Allah's Messenger (ﷺ) raised both his hands and said, 'O Allah! Round about us and not on us. O Allah! On the plateaus, on the mountains, on the hills, in the valleys and on the places where trees grow.' So the rain stopped and we came out walking in the sun." Sharik asked Anas whether it was the same person who had asked for the rain (the last Friday). Anas replied that he did not know}}
\hadithdefcmd{bukhari}{1014}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ شَرِيكٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ يَوْمَ جُمُعَةٍ مِنْ بَابٍ كَانَ نَحْوَ دَارِ الْقَضَاءِ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يَخْطُبُ، فَاسْتَقْبَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَائِمًا ثُمَّ قَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الأَمْوَالُ وَانْقَطَعَتِ السُّبُلُ، فَادْعُ اللَّهَ يُغِيثُنَا فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ أَغِثْنَا، اللَّهُمَّ أَغِثْنَا، اللَّهُمَّ أَغِثْنَا ‏"‏‏.‏ قَالَ أَنَسٌ وَلاَ وَاللَّهِ مَا نَرَى فِي السَّمَاءِ مِنْ سَحَابٍ، وَلاَ قَزَعَةً، وَمَا بَيْنَنَا وَبَيْنَ سَلْعٍ مِنْ بَيْتٍ وَلاَ دَارٍ‏.‏ قَالَ فَطَلَعَتْ مِنْ وَرَائِهِ سَحَابَةٌ مِثْلُ التُّرْسِ، فَلَمَّا تَوَسَّطَتِ السَّمَاءَ انْتَشَرَتْ ثُمَّ أَمْطَرَتْ، فَلاَ وَاللَّهِ مَا رَأَيْنَا الشَّمْسَ سِتًّا، ثُمَّ دَخَلَ رَجُلٌ مِنْ ذَلِكَ الْبَابِ فِي الْجُمُعَةِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يَخْطُبُ، فَاسْتَقْبَلَهُ قَائِمًا فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الأَمْوَالُ وَانْقَطَعَتِ السُّبُلُ، فَادْعُ اللَّهَ يُمْسِكْهَا عَنَّا‏.‏ قَالَ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا، اللَّهُمَّ عَلَى الآكَامِ وَالظِّرَابِ وَبُطُونِ الأَوْدِيَةِ وَمَنَابِتِ الشَّجَرِ ‏"‏‏.‏ قَالَ فَأَقْلَعَتْ وَخَرَجْنَا نَمْشِي فِي الشَّمْسِ‏.‏ قَالَ شَرِيكٌ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ أَهُوَ الرَّجُلُ الأَوَّلُ فَقَالَ مَا أَدْرِي‏.‏\hadithno{1014}\hadithtrans{Narrated Sharik:Anas bin Malik said, "A person entered the Mosque on a Friday through the gate facing the Daril- Qada' and Allah's Messenger (ﷺ) was standing delivering the Khutba (sermon). The man stood in front of Allah's Messenger (ﷺ) and said, 'O Allah's Messenger (ﷺ), livestock are dying and the roads are cut off; please pray to Allah for rain.' So Allah's Messenger (ﷺ) raised both his hands and said, 'O Allah! Bless us with rain. O Allah! Bless us with rain. O Allah! Bless us with rain!" Anas added, "By Allah, there were no clouds in the sky and there was no house or building between us and the mountain of Sila'. Then a big cloud like a shield appeared from behind it (i.e. Sila' Mountain) and when it came in the middle of the sky, it spread and then rained. By Allah! We could not see the sun for a week. The next Friday, a person entered through the same gate and Allah's Messenger (ﷺ) was delivering the Friday Khutba and the man stood in front of him and said, 'O Allah's Messenger (ﷺ)! The livestock are dying and the roads are cut off; Please pray to Allah to withhold rain.' " Anas added, "Allah's Messenger (ﷺ) raised both his hands and said, 'O Allah! Round about us and not on us. O Allah!' On the plateaus, on the mountains, on the hills, in the valleys and on the places where trees grow.' " Anas added, "The rain stopped and we came out, walking in the sun." Sharik asked Anas whether it was the same person who had asked for rain the previous Friday. Anas replied that he did not know}}
\hadithdefcmd{bukhari}{1015}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ إِذْ جَاءَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ، قَحَطَ الْمَطَرُ فَادْعُ اللَّهَ أَنْ يَسْقِيَنَا‏.‏ فَدَعَا فَمُطِرْنَا، فَمَا كِدْنَا أَنْ نَصِلَ إِلَى مَنَازِلِنَا فَمَا زِلْنَا نُمْطَرُ إِلَى الْجُمُعَةِ الْمُقْبِلَةِ‏.‏ قَالَ فَقَامَ ذَلِكَ الرَّجُلُ أَوْ غَيْرُهُ فَقَالَ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَصْرِفَهُ عَنَّا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏‏.‏ قَالَ فَلَقَدْ رَأَيْتُ السَّحَابَ يَتَقَطَّعُ يَمِينًا وَشِمَالاً يُمْطَرُونَ وَلاَ يُمْطَرُ أَهْلُ الْمَدِينَةِ‏.‏\hadithno{1015}\hadithtrans{Narrated Qatada:Anas said, "While Allah's Messenger (ﷺ) was delivering the Friday Khutba (sermon) a man came and said, 'O Allah's Messenger (ﷺ)! Rain is scarce; please ask Allah to bless us with rain.' So he invoked Allah for it, and it rained so much that we could hardly reach our homes and it continued raining till the next Friday." Anas further said, "Then the same or some other person stood up and said, 'O Allah's Apostle! Invoke Allah to withhold the rain.' On that, Allah's Messenger (ﷺ) said, 'O Allah! Round about us and not on us.'" Anas added, "I saw the clouds dispersing right and left and it continued to rain but not over Medina}}
\hadithdefcmd{bukhari}{1016}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ هَلَكَتِ الْمَوَاشِي وَتَقَطَّعَتِ السُّبُلُ‏.‏ فَدَعَا، فَمُطِرْنَا مِنَ الْجُمُعَةِ إِلَى الْجُمُعَةِ، ثُمَّ جَاءَ فَقَالَ تَهَدَّمَتِ الْبُيُوتُ وَتَقَطَّعَتِ السُّبُلُ، وَهَلَكَتِ الْمَوَاشِي فَادْعُ اللَّهَ يُمْسِكْهَا‏.‏ فَقَامَ صلى الله عليه وسلم فَقَالَ ‏ "‏ اللَّهُمَّ عَلَى الآكَامِ وَالظِّرَابِ وَالأَوْدِيَةِ وَمَنَابِتِ الشَّجَرِ ‏"‏‏.‏ فَانْجَابَتْ عَنِ الْمَدِينَةِ انْجِيَابَ الثَّوْبِ‏.‏\hadithno{1016}\hadithtrans{Narrated Anas:A man came to the Prophet (ﷺ) and said, "Livestock are destroyed and the roads are cut off." So Allah's Messenger (ﷺ) invoked Allah for rain and it rained from that Friday till the next Friday. The same person came again and said, "Houses have collapsed, roads are cut off, and the livestock are destroyed. Please pray to Allah to withhold the rain." Allah's Messenger (ﷺ) (stood up and) said, "O Allah! (Let it rain) on the plateaus, on the hills, in the valleys and over the places where trees grow." So the clouds cleared away from Medina as clothes are taken off}}
\hadithdefcmd{bukhari}{1017}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، هَلَكَتِ الْمَوَاشِي وَانْقَطَعَتِ السُّبُلُ، فَادْعُ اللَّهَ، فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَمُطِرُوا مِنْ جُمُعَةٍ إِلَى جُمُعَةٍ، فَجَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، تَهَدَّمَتِ الْبُيُوتُ وَتَقَطَّعَتِ السُّبُلُ وَهَلَكَتِ الْمَوَاشِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ عَلَى رُءُوسِ الْجِبَالِ وَالآكَامِ وَبُطُونِ الأَوْدِيَةِ وَمَنَابِتِ الشَّجَرِ ‏"‏‏.‏ فَانْجَابَتْ عَنِ الْمَدِينَةِ انْجِيَابَ الثَّوْبِ‏.‏\hadithno{1017}\hadithtrans{Narrated Anas bin Malik:A man came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Livestock are destroyed and the roads are cut off. So please invoke Allah." So Allah's Messenger (ﷺ) prayed and it rained from that Friday to the next Friday. Then he came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Houses have collapsed, roads are cut off and the livestock are destroyed." So Allah's Messenger (ﷺ) prayed, "O Allah! (Let it rain) on the tops of mountains, on the plateaus, in the valleys and over the places where trees grow." So the clouds cleared away from Medina as clothes are taken off}}
\hadithdefcmd{bukhari}{1018}{حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا مُعَافَى بْنُ عِمْرَانَ، عَنِ الأَوْزَاعِيِّ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، شَكَا إِلَى النَّبِيِّ صلى الله عليه وسلم هَلاَكَ الْمَالِ وَجَهْدَ الْعِيَالِ، فَدَعَا اللَّهَ يَسْتَسْقِي، وَلَمْ يَذْكُرْ أَنَّهُ حَوَّلَ رِدَاءَهُ وَلاَ اسْتَقْبَلَ الْقِبْلَةَ‏.‏\hadithno{1018}\hadithtrans{Narrated Anas bin Malik:A man complained to the Prophet (ﷺ) about the destruction of livestock and property and the hunger of the offspring. So he invoked (Allah for rain. The narrator (Anas) did not mention that the Prophet (ﷺ) had worn his cloak inside out or faced the Qibla}}
\hadithdefcmd{bukhari}{1019}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الْمَوَاشِي، وَتَقَطَّعَتِ السُّبُلُ، فَادْعُ اللَّهَ‏.‏ فَدَعَا اللَّهَ، فَمُطِرْنَا مِنَ الْجُمُعَةِ إِلَى الْجُمُعَةِ، فَجَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، تَهَدَّمَتِ الْبُيُوتُ وَتَقَطَّعَتِ السُّبُلُ وَهَلَكَتِ الْمَوَاشِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ عَلَى ظُهُورِ الْجِبَالِ وَالآكَامِ وَبُطُونِ الأَوْدِيَةِ وَمَنَابِتِ الشَّجَرِ ‏"‏‏.‏ فَانْجَابَتْ عَنِ الْمَدِينَةِ انْجِيَابَ الثَّوْبِ‏.‏\hadithno{1019}\hadithtrans{Narrated Anas bin Malik:A man came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Livestock are destroyed and the roads are cut off; so please invoke Allah." So Allah's Messenger (ﷺ) prayed for rain and it rained from that Friday till the next Friday. Then a man came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! The houses have collapsed, roads are cut off and the livestock are destroyed." So Allah's Messenger (ﷺ) said, "O Allah ! (Let it rain) on the tops of the mountains, on the plateaus, in the valleys and over the places where trees grow." So the clouds cleared away from Medina as clothes are taken off}}
\hadithdefcmd{bukhari}{1020}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنْ سُفْيَانَ، حَدَّثَنَا مَنْصُورٌ، وَالأَعْمَشُ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ أَتَيْتُ ابْنَ مَسْعُودٍ فَقَالَ إِنَّ قُرَيْشًا أَبْطَئُوا عَنِ الإِسْلاَمِ،، فَدَعَا عَلَيْهِمُ النَّبِيُّ صلى الله عليه وسلم فَأَخَذَتْهُمْ سَنَةٌ حَتَّى هَلَكُوا فِيهَا وَأَكَلُوا الْمَيْتَةَ وَالْعِظَامَ، فَجَاءَهُ أَبُو سُفْيَانَ فَقَالَ يَا مُحَمَّدُ، جِئْتَ تَأْمُرُ بِصِلَةِ الرَّحِمِ، وَإِنَّ قَوْمَكَ هَلَكُوا، فَادْعُ اللَّهَ‏.‏ فَقَرَأَ ‏\{‏فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ‏\}‏ ثُمَّ عَادُوا إِلَى كُفْرِهِمْ فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏يَوْمَ نَبْطِشُ الْبَطْشَةَ الْكُبْرَى‏\}‏ يَوْمَ بَدْرٍ‏.‏ قَالَ وَزَادَ أَسْبَاطٌ عَنْ مَنْصُورٍ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم، فَسُقُوا الْغَيْثَ، فَأَطْبَقَتْ عَلَيْهِمْ سَبْعًا، وَشَكَا النَّاسُ كَثْرَةَ الْمَطَرِ فَقَالَ ‏"‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏‏.‏ فَانْحَدَرَتِ السَّحَابَةُ عَنْ رَأْسِهِ، فَسُقُوا النَّاسُ حَوْلَهُمْ‏.‏\hadithno{1020}\hadithtrans{Narrated Masruq:One day I went to Ibn Mas`ud who said, "When Quraish delayed in embracing Islam, the Prophet (ﷺ) invoked Allah to curse them, so they were afflicted with a (famine) year because of which many of them died and they ate the carcasses and Abu Sufyan came to the Prophet (ﷺ) and said, 'O Muhammad! You came to order people to keep good relation with kith and kin and your nation is being destroyed, so invoke Allah.' So the Prophet (ﷺ) recited the Holy verses of Surat-Ad-Dukhan: 'Then watch you For the day that The sky will Bring forth a kind Of smoke Plainly visible.' (44.10) When the famine was taken off, the people renegade once again as nonbelievers. The statement of Allah, (in Sura "Ad- Dukhan"-44) refers to that: 'On the day when We shall seize You with a mighty grasp.' (44.16) And that was what happened on the day of the battle of Badr." Asbat added on the authority of Mansur, "Allah's Messenger (ﷺ) prayed for them and it rained heavily for seven days. So the people complained of the excessive rain. The Prophet (ﷺ) said, 'O Allah! (Let it rain) around us and not on us.' So the clouds dispersed over his head and it rained over the surroundings}}
\hadithdefcmd{bukhari}{1021}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ جُمُعَةٍ، فَقَامَ النَّاسُ فَصَاحُوا فَقَالُوا يَا رَسُولَ اللَّهِ، قَحَطَ الْمَطَرُ وَاحْمَرَّتِ الشَّجَرُ وَهَلَكَتِ الْبَهَائِمُ، فَادْعُ اللَّهَ يَسْقِينَا‏.‏ فَقَالَ ‏"‏ اللَّهُمَّ اسْقِنَا ‏"‏‏.‏ مَرَّتَيْنِ، وَايْمُ اللَّهِ مَا نَرَى فِي السَّمَاءِ قَزَعَةً مِنْ سَحَابٍ، فَنَشَأَتْ سَحَابَةٌ وَأَمْطَرَتْ، وَنَزَلَ عَنِ الْمِنْبَرِ فَصَلَّى، فَلَمَّا انْصَرَفَ لَمْ تَزَلْ تُمْطِرُ إِلَى الْجُمُعَةِ الَّتِي تَلِيهَا، فَلَمَّا قَامَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ صَاحُوا إِلَيْهِ تَهَدَّمَتِ الْبُيُوتُ وَانْقَطَعَتِ السُّبُلُ، فَادْعُ اللَّهَ يَحْبِسُهَا عَنَّا‏.‏ فَتَبَسَّمَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏‏.‏ فَكُشِطَتِ الْمَدِينَةُ، فَجَعَلَتْ تُمْطِرُ حَوْلَهَا وَلاَ تَمْطُرُ بِالْمَدِينَةِ قَطْرَةً، فَنَظَرْتُ إِلَى الْمَدِينَةِ وَإِنَّهَا لَفِي مِثْلِ الإِكْلِيلِ‏.‏\hadithno{1021}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) was delivering the Khutba (sermon) on a Friday when the people stood up, shouted and said, "O Allah's Messenger (ﷺ)! There is no rain (drought), the trees have dried and the livestock are destroyed; Please pray to Allah for rain." So Allah's Messenger (ﷺ) said twice, "O Allah! Bless us with rain." By Allah, there was no trace of cloud in the sky and suddenly the sky became overcast with clouds and it started raining. The Prophet (ﷺ) came down the pulpit and offered the prayer. When he came back from the prayer (to his house) it was raining and it rained continuously till the next Friday. When the Prophet started delivering the Friday Khutba (sermon), the people started shouting and said to him, "The houses have collapsed and the roads are cut off; so please pray to Allah to withhold the rain." So the Prophet (ﷺ) smiled and said, "O Allah! Round about us and not on us." So the sky became clear over Medina but it kept on raining over the outskirts (of Medina) and not a single drop of rain fell over Medina. I looked towards the sky which was as bright and clear as a crown}}
\hadithdefcmd{bukhari}{1022}{وَقَالَ لَنَا أَبُو نُعَيْمٍ عَنْ زُهَيْرٍ، عَنْ أَبِي إِسْحَاقَ، خَرَجَ عَبْدُ اللَّهِ بْنُ يَزِيدَ الأَنْصَارِيُّ وَخَرَجَ مَعَهُ الْبَرَاءُ بْنُ عَازِبٍ وَزَيْدُ بْنُ أَرْقَمَ رضى الله عنهم فَاسْتَسْقَى، فَقَامَ بِهِمْ عَلَى رِجْلَيْهِ عَلَى غَيْرِ مِنْبَرٍ فَاسْتَغْفَرَ، ثُمَّ صَلَّى رَكْعَتَيْنِ يَجْهَرُ بِالْقِرَاءَةِ وَلَمْ يُؤَذِّنْ، وَلَمْ يُقِمْ‏.‏ قَالَ أَبُو إِسْحَاقَ وَرَأَى عَبْدُ اللَّهِ بْنُ يَزِيدَ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{1022}\hadithtrans{Narrated 'Abdullah bin Yazid Al-Ansari that he went out with Al-Bara' bin 'Azib, and Zaid bin Arqam and invoked for rain. He ('Abdullah bin Yazid) stood up but not on a pulpit and invoked Allah for rain and then offered two Rak'a prayers with loud recitation without pronouncing Adhan or Iqama. Abu Ishaq said that 'Abdullah bin Yazid had seen the Prophet (ﷺ) (doing the same)}}
\hadithdefcmd{bukhari}{1023}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَبَّادُ بْنُ تَمِيمٍ، أَنَّ عَمَّهُ ـ وَكَانَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ بِالنَّاسِ يَسْتَسْقِي لَهُمْ، فَقَامَ فَدَعَا اللَّهَ قَائِمًا، ثُمَّ تَوَجَّهَ قِبَلَ الْقِبْلَةِ، وَحَوَّلَ رِدَاءَهُ فَأُسْقُوا‏.‏\hadithno{1023}\hadithtrans{Narrated `Abbad bin Tamim:that his uncle (who was one of the companions of the Prophet) had told him, "The Prophet (ﷺ) went out with the people to invoke Allah for rain for them. He stood up and invoked Allah for rain, then faced the Qibla and turned his cloak (inside out) and it rained}}
\hadithdefcmd{bukhari}{1024}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم يَسْتَسْقِي فَتَوَجَّهَ إِلَى الْقِبْلَةِ يَدْعُو، وَحَوَّلَ رِدَاءَهُ، ثُمَّ صَلَّى رَكْعَتَيْنِ جَهَرَ فِيهِمَا بِالْقِرَاءَةِ‏.‏\hadithno{1024}\hadithtrans{Narrated `Abbad bin Tamim:from his uncle who said, "The Prophet (ﷺ) went out to invoke Allah for rain. He faced the Qibla invoking Allah. He turned over his cloak (inside out) and then offered two rak`at and recited the Qur'an aloud in them}}
\hadithdefcmd{bukhari}{1025}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَوْمَ خَرَجَ يَسْتَسْقِي قَالَ فَحَوَّلَ إِلَى النَّاسِ ظَهْرَهُ، وَاسْتَقْبَلَ الْقِبْلَةَ يَدْعُو، ثُمَّ حَوَّلَ رِدَاءَهُ، ثُمَّ صَلَّى لَنَا رَكْعَتَيْنِ جَهَرَ فِيهِمَا بِالْقِرَاءَةِ‏.‏\hadithno{1025}\hadithtrans{Narrated `Abbad bin Tamim from his uncle:"I saw the Prophet (ﷺ) on the day when he went out to offer the Istisqa' prayer. He turned his back towards the people and faced the Qibla and asked Allah for rain. Then he turned his cloak inside out and led us in a two rak`at prayer and recited the Qur'an aloud in them}}
\hadithdefcmd{bukhari}{1026}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَسْقَى فَصَلَّى رَكْعَتَيْنِ، وَقَلَبَ رِدَاءَهُ‏.‏\hadithno{1026}\hadithtrans{Narrated `Abbad bin Tamim from his uncle who said:"The Prophet (ﷺ) invoked Allah for rain and offered a two rak`at prayer and he put his cloak inside out}}
\hadithdefcmd{bukhari}{1027}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، سَمِعَ عَبَّادَ بْنَ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْمُصَلَّى يَسْتَسْقِي، وَاسْتَقْبَلَ الْقِبْلَةَ فَصَلَّى رَكْعَتَيْنِ، وَقَلَبَ رِدَاءَهُ‏.‏ قَالَ سُفْيَانُ فَأَخْبَرَنِي الْمَسْعُودِيُّ عَنْ أَبِي بَكْرٍ قَالَ جَعَلَ الْيَمِينَ عَلَى الشِّمَالِ‏.‏\hadithno{1027}\hadithtrans{Narrated `Abbad bin Tamim from his uncle who said:"The Prophet (ﷺ) went out to the Musalla to offer the Istisqa' prayer, faced the Qibla and offered a two rak`at prayer and turned his cloak inside out." Narrated Abu Bakr, "The Prophet (ﷺ) put the right side of his cloak on his left side}}
\hadithdefcmd{bukhari}{1028}{حَدَّثَنَا مُحَمَّدٌ، قَالَ أَخْبَرَنَا عَبْدُ الْوَهَّابِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ مُحَمَّدٍ، أَنَّ عَبَّادَ بْنَ تَمِيمٍ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ زَيْدٍ الأَنْصَارِيَّ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ إِلَى الْمُصَلَّى يُصَلِّي، وَأَنَّهُ لَمَّا دَعَا ـ أَوْ أَرَادَ أَنْ يَدْعُوَ ـ اسْتَقْبَلَ الْقِبْلَةَ وَحَوَّلَ رِدَاءَهُ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ ابْنُ زَيْدٍ هَذَا مَازِنِيٌّ، وَالأَوَّلُ كُوفِيٌّ هُوَ ابْنُ يَزِيدَ‏.‏\hadithno{1028}\hadithtrans{Narrated `Abdullah bin Zaid Al-Ansari:The Prophet (ﷺ) went out towards the Musalla in order to offer the Istisqa' prayer and when he intended to invoke (Allah) or started invoking, he faced the Qibla and turned his cloak inside out}}
\hadithdefcmd{bukhari}{1029}{قَالَ أَيُّوبُ بْنُ سُلَيْمَانَ حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي أُوَيْسٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، قَالَ يَحْيَى بْنُ سَعِيدٍ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، قَالَ أَتَى رَجُلٌ أَعْرَابِيٌّ مِنْ أَهْلِ الْبَدْوِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ الْجُمُعَةِ فَقَالَ يَا رَسُولَ اللَّهِ، هَلَكَتِ الْمَاشِيَةُ هَلَكَ الْعِيَالُ هَلَكَ النَّاسُ‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ يَدْعُو، وَرَفَعَ النَّاسُ أَيْدِيَهُمْ مَعَهُ يَدْعُونَ، قَالَ فَمَا خَرَجْنَا مِنَ الْمَسْجِدِ حَتَّى مُطِرْنَا، فَمَا زِلْنَا نُمْطَرُ حَتَّى كَانَتِ الْجُمُعَةُ الأُخْرَى، فَأَتَى الرَّجُلُ إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ، بَشِقَ الْمُسَافِرُ، وَمُنِعَ الطَّرِيقُ‏.‏\hadithno{1029}\hadithtrans{Narrated Anas bin Malik:A bedouin came to Allah's Messenger (ﷺ) on a Friday and said, "O Allah's Messenger ! The livestock, the offspring, and the people have perished." So, Allah's Messenger (ﷺ) raised both his hands invoking Allah (for rain) and the people too raised their hands with Allah's Messenger (ﷺ) invoking Allah (for rain). We had not left the mosque when it started raining. It rained till the next Friday when the same man came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger! The travelers are compelled to postpone their journeys (because of excessive rain) and the roads are overflowed}}
\hadithdefcmd{bukhari}{1030}{وَقَالَ الأُوَيْسِيُّ حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَشَرِيكٍ، سَمِعَا أَنَسًا، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ رَفَعَ يَدَيْهِ حَتَّى رَأَيْتُ بَيَاضَ إِبْطَيْهِ‏.‏\hadithno{1030}\hadithtrans{The narrator Anas added that the Prophet (ﷺ) raised his hands (during the invocation) to such an extent that the whiteness of his armpits was visible}}
\hadithdefcmd{bukhari}{1031}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، وَابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يَرْفَعُ يَدَيْهِ فِي شَىْءٍ مِنْ دُعَائِهِ إِلاَّ فِي الاِسْتِسْقَاءِ، وَإِنَّهُ يَرْفَعُ حَتَّى يُرَى بَيَاضُ إِبْطَيْهِ‏.‏\hadithno{1031}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) never raised his hands for any invocation except for that of Istisqa' and he used to raise them so much that the whiteness of his armpits became visible. (Note: It may be that Anas did not see the Prophet (ﷺ) raising his hands, but it is narrated that the Prophet (ﷺ) used to raise his hands for invocations other than Istisqa. See Hadith No. 807 \& 808 and also see Hadith No. 612, Vol}}
\hadithdefcmd{bukhari}{1032}{حَدَّثَنَا مُحَمَّدٌ ـ هُوَ ابْنُ مُقَاتِلٍ أَبُو الْحَسَنِ الْمَرْوَزِيُّ ـ قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا رَأَى الْمَطَرَ قَالَ ‏ "‏ صَيِّبًا نَافِعًا ‏"‏‏.‏ تَابَعَهُ الْقَاسِمُ بْنُ يَحْيَى عَنْ عُبَيْدِ اللَّهِ‏.‏ وَرَوَاهُ الأَوْزَاعِيُّ وَعُقَيْلٌ عَنْ نَافِعٍ‏.‏\hadithno{1032}\hadithtrans{Narrated Aisha:Whenever Allah's Messenger (ﷺ) saw the rain, he used to say, "O Allah! Let it be a strong fruitful rain}}
\hadithdefcmd{bukhari}{1033}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، قَالَ أَخْبَرَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ أَصَابَتِ النَّاسَ سَنَةٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ عَلَى الْمِنْبَرِ يَوْمَ الْجُمُعَةِ قَامَ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ، هَلَكَ الْمَالُ وَجَاعَ الْعِيَالُ، فَادْعُ اللَّهَ لَنَا أَنْ يَسْقِيَنَا‏.‏ قَالَ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ، وَمَا فِي السَّمَاءِ قَزَعَةٌ، قَالَ فَثَارَ سَحَابٌ أَمْثَالُ الْجِبَالِ، ثُمَّ لَمْ يَنْزِلْ عَنْ مِنْبَرِهِ حَتَّى رَأَيْتُ الْمَطَرَ يَتَحَادَرُ عَلَى لِحْيَتِهِ، قَالَ فَمُطِرْنَا يَوْمَنَا ذَلِكَ، وَفِي الْغَدِ وَمِنْ بَعْدِ الْغَدِ وَالَّذِي يَلِيهِ إِلَى الْجُمُعَةِ الأُخْرَى، فَقَامَ ذَلِكَ الأَعْرَابِيُّ أَوْ رَجُلٌ غَيْرُهُ فَقَالَ يَا رَسُولَ اللَّهِ، تَهَدَّمَ الْبِنَاءُ وَغَرِقَ الْمَالُ، فَادْعُ اللَّهَ لَنَا‏.‏ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ وَقَالَ ‏ "‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏‏.‏ قَالَ فَمَا جَعَلَ يُشِيرُ بِيَدِهِ إِلَى نَاحِيَةٍ مِنَ السَّمَاءِ إِلاَّ تَفَرَّجَتْ حَتَّى صَارَتِ الْمَدِينَةُ فِي مِثْلِ الْجَوْبَةِ، حَتَّى سَالَ الْوَادِي ـ وَادِي قَنَاةَ ـ شَهْرًا‏.‏ قَالَ فَلَمْ يَجِئْ أَحَدٌ مِنْ نَاحِيَةٍ إِلاَّ حَدَّثَ بِالْجَوْدِ‏.‏\hadithno{1033}\hadithtrans{Narrated Anas bin Malik:In the lifetime of Allah's Messenger (ﷺ) the people were afflicted with a (famine) year. While the Prophet was delivering the Khutba (sermon) on the pulpit on a Friday, a Bedouin stood up and said, "O Allah's Messenger (ﷺ)! The livestock are dying and the families (offspring) are hungry: please pray to Allah to bless us with rain." Allah's Messenger (ﷺ) raised both his hands towards the sky and at that time there was not a trace of cloud in the sky. Then the clouds started gathering like mountains. Before he got down from the pulpit I saw rainwater trickling down his beard. It rained that day, the next day, the third day, the fourth day and till the next Friday, when the same Bedouin or some other person stood up (during the Friday Khutba) and said, "O Allah's Messenger (ﷺ)! The houses have collapsed and the livestock are drowned. Please invoke Allah for us." So Allah's Messenger (ﷺ) raised both his hands and said, "O Allah! Around us and not on us." Whichever side the Prophet (ﷺ) directed his hand, the clouds dispersed from there till a hole (in the clouds) was formed over Medina. The valley of Qanat remained flowing (with water) for one month and none, came from outside who didn't talk about the abundant rain}}
\hadithdefcmd{bukhari}{1034}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي حُمَيْدٌ، أَنَّهُ سَمِعَ أَنَسًا، يَقُولُ كَانَتِ الرِّيحُ الشَّدِيدَةُ إِذَا هَبَّتْ عُرِفَ ذَلِكَ فِي وَجْهِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1034}\hadithtrans{Narrated Anas:Whenever a strong wind blew, anxiety appeared on the face of the Prophet (fearing that wind might be a sign of Allah's wrath)}}
\hadithdefcmd{bukhari}{1035}{حَدَّثَنَا مُسْلِمٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ نُصِرْتُ بِالصَّبَا، وَأُهْلِكَتْ عَادٌ بِالدَّبُورِ ‏"‏‏.‏\hadithno{1035}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "I was granted victory with As-Saba and the nation of 'Ad was destroyed by Ad- Dabur (westerly wind)}}
\hadithdefcmd{bukhari}{1036}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، قَالَ أَخْبَرَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يُقْبَضَ الْعِلْمُ، وَتَكْثُرَ الزَّلاَزِلُ، وَيَتَقَارَبَ الزَّمَانُ، وَتَظْهَرَ الْفِتَنُ، وَيَكْثُرَ الْهَرْجُ ـ وَهْوَ الْقَتْلُ الْقَتْلُ ـ حَتَّى يَكْثُرَ فِيكُمُ الْمَالُ فَيَفِيضُ ‏"‏‏.‏\hadithno{1036}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour (Last Day) will not be established until (religious) knowledge will be taken away (by the death of religious learned men), earthquakes will be very frequent, time will pass quickly, afflictions will appear, murders will increase and money will overflow amongst you." (See Hadith No. 85 Vol)}}
\hadithdefcmd{bukhari}{1037}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا حُسَيْنُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اللَّهُمَّ بَارِكْ لَنَا فِي شَامِنَا وَفِي يَمَنِنَا‏.‏ قَالَ قَالُوا وَفِي نَجْدِنَا قَالَ قَالَ اللَّهُمَّ بَارِكْ لَنَا فِي شَامِنَا وَفِي يَمَنِنَا‏.‏ قَالَ قَالُوا وَفِي نَجْدِنَا قَالَ قَالَ هُنَاكَ الزَّلاَزِلُ وَالْفِتَنُ، وَبِهَا يَطْلُعُ قَرْنُ الشَّيْطَانِ‏.‏\hadithno{1037}\hadithtrans{Narrated Ibn `Umar:(The Prophet) said, "O Allah! Bless our Sham and our Yemen." People said, "Our Najd as well." The Prophet again said, "O Allah! Bless our Sham and Yemen." They said again, "Our Najd as well." On that the Prophet (ﷺ) said, "There will appear earthquakes and afflictions, and from there will come out the side of the head of Satan}}
\hadithdefcmd{bukhari}{1038}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الصُّبْحِ بِالْحُدَيْبِيَةِ عَلَى إِثْرِ سَمَاءٍ كَانَتْ مِنَ اللَّيْلَةِ، فَلَمَّا انْصَرَفَ النَّبِيُّ صلى الله عليه وسلم أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ هَلْ تَدْرُونَ مَاذَا قَالَ رَبُّكُمْ ‏"‏‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ أَصْبَحَ مِنْ عِبَادِي مُؤْمِنٌ بِي وَكَافِرٌ، فَأَمَّا مَنْ قَالَ مُطِرْنَا بِفَضْلِ اللَّهِ وَرَحْمَتِهِ‏.‏ فَذَلِكَ مُؤْمِنٌ بِي كَافِرٌ بِالْكَوْكَبِ، وَأَمَّا مَنْ قَالَ بِنَوْءِ كَذَا وَكَذَا‏.‏ فَذَلِكَ كَافِرٌ بِي مُؤْمِنٌ بِالْكَوْكَبِ ‏"‏‏.‏\hadithno{1038}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:Allah's Messenger (ﷺ) led the morning prayer in Al-Hudaibiya and it had rained the previous night. When the Prophet (ﷺ) had finished the prayer he faced the people and said, "Do you know what your Lord has said?" They replied, "Allah and His Apostle know better." (The Prophet (ﷺ) said), "Allah says, 'In this morning some of My worshipers remained as true believers and some became non-believers; he who said that it had rained with the blessing and mercy of Allah is the one who believes in Me and does not believe in star, but he who said it had rained because of such and such (star) is a disbeliever in Me and is a believer in star}}
\hadithdefcmd{bukhari}{1039}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِفْتَاحُ الْغَيْبِ خَمْسٌ لاَ يَعْلَمُهَا إِلاَّ اللَّهُ لاَ يَعْلَمُ أَحَدٌ مَا يَكُونُ فِي غَدٍ، وَلاَ يَعْلَمُ أَحَدٌ مَا يَكُونُ فِي الأَرْحَامِ، وَلاَ تَعْلَمُ نَفْسٌ مَاذَا تَكْسِبُ غَدًا، وَمَا تَدْرِي نَفْسٌ بِأَىِّ أَرْضٍ تَمُوتُ، وَمَا يَدْرِي أَحَدٌ مَتَى يَجِيءُ الْمَطَرُ ‏"‏‏.‏\hadithno{1039}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Keys of the unseen knowledge are five which nobody knows but Allah . . . nobody knows what will happen tomorrow; nobody knows what is in the womb; nobody knows what he will gain tomorrow; nobody knows at what place he will die; and nobody knows when it will rain}}
